@@ -2,18 +2,17 @@
 import json
 import logging
 import typing
-from typing import Any, Optional, Union
-
-import six
-from box import Box
+from typing import Any, Dict, Optional, Union
 
 import brewtils.models
 import brewtils.schemas
+import six  # type: ignore
+from box import Box  # type: ignore
 from brewtils.models import BaseModel
 
 try:
-    from collections.abc import Iterable
-except ImportError:
+    from collections.abc import Iterable  # type: ignore  # noqa
+except ImportError:  # pragma: no cover
     from collections import Iterable
 
 
@@ -31,6 +30,7 @@ class SchemaParser(object):
         "InstanceSchema": brewtils.models.Instance,
         "IntervalTriggerSchema": brewtils.models.IntervalTrigger,
         "JobSchema": brewtils.models.Job,
+        "JobExport": brewtils.models.Job,
         "LoggingConfigSchema": brewtils.models.LoggingConfig,
         "QueueSchema": brewtils.models.Queue,
         "ParameterSchema": brewtils.models.Parameter,
@@ -43,7 +43,7 @@ class SchemaParser(object):
         "FileChunkSchema": brewtils.models.FileChunk,
         "FileStatusSchema": brewtils.models.FileStatus,
         "RequestTemplateSchema": brewtils.models.RequestTemplate,
-        "RoleSchema": brewtils.models.Role,
+        "LegacyRoleSchema": brewtils.models.LegacyRole,
         "SystemSchema": brewtils.models.System,
         "OperationSchema": brewtils.models.Operation,
         "RunnerSchema": brewtils.models.Runner,
@@ -262,7 +262,9 @@ class SchemaParser(object):
         Returns:
             A Role object
         """
-        return cls.parse(role, brewtils.models.Role, from_string=from_string, **kwargs)
+        return cls.parse(
+            role, brewtils.models.LegacyRole, from_string=from_string, **kwargs
+        )
 
     @classmethod
     def parse_refresh_token(cls, refresh_token, from_string=False, **kwargs):
@@ -298,6 +300,35 @@ class SchemaParser(object):
         """
         return cls.parse(job, brewtils.models.Job, from_string=from_string, **kwargs)
 
+    @classmethod
+    def parse_job_ids(cls, job_id_list, from_string=False, **kwargs):
+        """Convert raw JSON string or list of strings to a list of job ids.
+
+        Passes a list of strings through unaltered if from_string is False.
+
+        Args:
+            job_id_list: Raw input
+            from_string: True if input is a JSON string, False otherwise
+            **kwargs: Additional parameters to be passed to the Schema (e.g. many=True)
+
+        Returns:
+            A list of job ids.
+        """
+        # this is needed by easy_client
+        #
+        # some functionality duplicated from the parse method because model not used
+        if job_id_list is None:  # pragma: no cover
+            raise TypeError("job_id_list can not be None")
+        if not bool(from_string):
+            if isinstance(job_id_list, list):
+                if len(job_id_list) > 0 and not all(
+                    map(lambda x: isinstance(x, str), job_id_list)
+                ):  # pragma: no cover
+                    raise TypeError("Not a list of strings")
+                return job_id_list
+
+        return json.dumps(job_id_list)
+
     @classmethod
     def parse_garden(cls, garden, from_string=False, **kwargs):
         """Convert raw JSON string or dictionary to a garden model object
@@ -363,7 +394,13 @@ class SchemaParser(object):
         )
 
     @classmethod
-    def parse(cls, data, model_class, from_string=False, **kwargs):
+    def parse(
+        cls,
+        data,  # type: Optional[Union[str, Dict[str, Any]]]
+        model_class,  # type: Any
+        from_string=False,  # type: bool
+        **kwargs  # type: Any
+    ):  # type: (...) -> Union[str, Dict[str, Any]]
         """Convert a JSON string or dictionary into a model object
 
         Args:
@@ -393,6 +430,7 @@ class SchemaParser(object):
             kwargs["many"] = True
 
         schema = getattr(brewtils.schemas, model_class.schema)(**kwargs)
+
         schema.context["models"] = cls._models
 
         return schema.loads(data).data if from_string else schema.load(data).data
@@ -639,7 +677,10 @@ class SchemaParser(object):
             Serialized representation
         """
         return cls.serialize(
-            role, to_string=to_string, schema_name=brewtils.models.Role.schema, **kwargs
+            role,
+            to_string=to_string,
+            schema_name=brewtils.models.LegacyRole.schema,
+            **kwargs
         )
 
     @classmethod
@@ -670,7 +711,7 @@ class SchemaParser(object):
             job: The job object(s) to be serialized.
             to_string: True to generate a JSON-formatted string, False to generate a
                 dictionary
-            **kwargs: Additional parameters to be passed to the shcema (e.g. many=True)
+            **kwargs: Additional parameters to be passed to the schema (e.g. many=True)
 
         Returns:
             Serialize representation of job.
@@ -679,6 +720,45 @@ class SchemaParser(object):
             job, to_string=to_string, schema_name=brewtils.models.Job.schema, **kwargs
         )
 
+    @classmethod
+    def serialize_job_ids(cls, job_id_list, to_string=True, **kwargs):
+        """Convert a list of IDS into serialized form expected by the export endpoint.
+
+        Args:
+            job_id_list: The list of Job id(s) to be serialized
+            to_string: True to generate a JSON-formatted string, False to generate a
+                dictionary
+            **kwargs: Additional parameters to be passed to the schema (e.g. many=True)
+
+        Returns:
+            Serialized representation of the job IDs
+        """
+        arg_dict = {"ids": job_id_list}
+
+        return cls.serialize(
+            arg_dict, to_string=to_string, schema_name="JobExportInputSchema", **kwargs
+        )
+
+    @classmethod
+    def serialize_job_for_import(cls, job, to_string=True, **kwargs):
+        """Convert a Job object into serialized form expected by the import endpoint.
+
+        The fields that an existing Job would have that a new Job should not (e.g. 'id')
+        are removed by the schema.
+
+        Args:
+            job: The Job to be serialized
+            to_string: True to generate a JSON-formatted string, False to generate a
+                dictionary
+            **kwargs: Additional parameters to be passed to the schema (e.g. many=True)
+
+        Returns:
+            Serialized representation of the Job
+        """
+        return cls.serialize(
+            job, to_string=to_string, schema_name="JobExportSchema", **kwargs
+        )
+
     @classmethod
     def serialize_garden(cls, garden, to_string=True, **kwargs):
         """Convert an garden model into serialized form
@@ -764,10 +844,10 @@ class SchemaParser(object):
         cls,
         model,  # type: Union[BaseModel, typing.Iterable[BaseModel], dict]
         to_string=False,  # type: bool
-        schema_name=None,  # type: str
+        schema_name=None,  # type: Optional[str]
         **kwargs  # type: Any
     ):
-        # type: (...) -> Optional[str]
+        # type: (...) -> Union[Dict[str, Any], Optional[str]]
         """Convert a model object or list of models into a dictionary or JSON string.
 
         This is potentially recursive - here's how this should work:
@@ -803,7 +883,10 @@ class SchemaParser(object):
             return schema.dumps(model).data if to_string else schema.dump(model).data
 
         # Explicitly force to_string to False so only original call returns a string
-        multiple = [cls.serialize(x, to_string=False, **kwargs) for x in model]
+        multiple = [
+            cls.serialize(x, to_string=False, schema_name=schema_name, **kwargs)
+            for x in model
+        ]
 
         return json.dumps(multiple) if to_string else multiple
 
